@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.14;
 use warnings;
 
 use Tickit;
@@ -10,8 +10,11 @@ use List::Util qw( min max );
 my $fillchar = "1";
 sub fillwin
 {
-   my $win = shift;
-   my ( $rb, $rect ) = @_;
+   my ( $win, undef, $info ) = @_;
+
+   my $rb   = $info->rb;
+   my $rect = $info->rect;
+
    foreach my $line ( $rect->linerange ) {
       $rb->text_at( $line, $rect->left, $fillchar x $rect->cols );
    }
@@ -27,16 +30,17 @@ foreach ( 1 .. 9 ) {
 my $rootwin = $tickit->rootwin;
 
 my @start;
-$rootwin->set_on_mouse( sub {
-   my ( $self, $ev ) = @_;
-   @start = ( $ev->line, $ev->col ) and return if $ev->type eq "press";
-   return unless $ev->type eq "release";
+$rootwin->bind_event( mouse => sub {
+   my ( $self, undef, $info ) = @_;
+   @start = ( $info->line, $info->col ) and return if $info->type eq "press";
 
-   my $top  = min( $start[0], $ev->line );
-   my $left = min( $start[1], $ev->col );
+   return unless $info->type eq "release";
 
-   my $bottom = max( $start[0], $ev->line ) + 1;
-   my $right  = max( $start[1], $ev->col )  + 1;
+   my $top  = min( $start[0], $info->line );
+   my $left = min( $start[1], $info->col );
+
+   my $bottom = max( $start[0], $info->line ) + 1;
+   my $right  = max( $start[1], $info->col )  + 1;
 
    $rootwin->expose( Tickit::Rect->new(
       top   => $top,
@@ -48,19 +52,19 @@ $rootwin->set_on_mouse( sub {
 
 my $win = $rootwin->make_sub( 5, 10, 15, 60 );
 $win->pen->chattr( fg => 1 );
-$win->set_on_expose( \&fillwin );
+$win->bind_event( expose => \&fillwin );
 
 my @subwins;
 
 push @subwins, $win->make_sub( 0, 0, 4, 4 );
 $subwins[-1]->pen->chattr( fg => 2 );
-$subwins[-1]->set_on_expose( \&fillwin );
+$subwins[-1]->bind_event( expose => \&fillwin );
 
 push @subwins, $win->make_sub( 6, 40, 2, 15 );
 $subwins[-1]->pen->chattr( fg => 3 );
-$subwins[-1]->set_on_expose( \&fillwin );
+$subwins[-1]->bind_event( expose => \&fillwin );
 
-$tickit->later( sub {
+$tickit->watch_later( sub {
       $rootwin->expose;
 } );
 
