@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-use strict;
+use v5.14;
 use warnings;
 
 use Tickit;
@@ -21,7 +21,7 @@ sub timer
    $static->set_text( "Counter: $counter" );
    $counter++;
 
-   $tickit->timer( after => 1, \&timer );
+   $tickit->watch_timer_after( 1, \&timer );
 }
 
 timer();
